<?php

namespace Hrm\Jobunit\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Jobunit\Models\Jobunit;

class JobunitPolicy
{

    /**
     * Determine if the given user can view the jobunit.
     *
     * @param UserPolicy $user
     * @param Jobunit $jobunit
     *
     * @return bool
     */
    public function view(UserPolicy $user, Jobunit $jobunit)
    {
        if ($user->canDo('jobunit.jobunit.view') && $user->isAdmin()) {
            return true;
        }

        return $jobunit->user_id == user_id() && $jobunit->user_type == user_type();
    }

    /**
     * Determine if the given user can create a jobunit.
     *
     * @param UserPolicy $user
     * @param Jobunit $jobunit
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('jobunit.jobunit.create');
    }

    /**
     * Determine if the given user can update the given jobunit.
     *
     * @param UserPolicy $user
     * @param Jobunit $jobunit
     *
     * @return bool
     */
    public function update(UserPolicy $user, Jobunit $jobunit)
    {
        if ($user->canDo('jobunit.jobunit.edit') && $user->isAdmin()) {
            return true;
        }

        return $jobunit->user_id == user_id() && $jobunit->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given jobunit.
     *
     * @param UserPolicy $user
     * @param Jobunit $jobunit
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Jobunit $jobunit)
    {
        return $jobunit->user_id == user_id() && $jobunit->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given jobunit.
     *
     * @param UserPolicy $user
     * @param Jobunit $jobunit
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Jobunit $jobunit)
    {
        if ($user->canDo('jobunit.jobunit.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given jobunit.
     *
     * @param UserPolicy $user
     * @param Jobunit $jobunit
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Jobunit $jobunit)
    {
        if ($user->canDo('jobunit.jobunit.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
