<?php

namespace Hrm\Jobunit\Providers;

use Illuminate\Support\ServiceProvider;

class JobunitServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'jobunit');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'jobunit');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerJobunit();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerJobunit()
    {
        $this->app->bind('jobunit', function($app) {
            return new Jobunit($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Jobunit', 'Lavalite\Jobunit\Facades\Jobunit');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('hrm.jobunit', function ($app) {
            return $this->app->make('Hrm\Jobunit\Jobunit');
        });

                // Bind Jobunit to repository
        $this->app->bind(
            'Hrm\Jobunit\Interfaces\JobunitRepositoryInterface',
            \Hrm\Jobunit\Repositories\Eloquent\JobunitRepository::class
        );

        $this->app->register(\Hrm\Jobunit\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Hrm\Jobunit\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and jobunit's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/jobunit.php', 'jobunit'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeJobunit::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['hrm.jobunit'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('hrm/jobunit.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/jobunit')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/jobunit')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
